@@ -4,17 +4,16 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = sprintf "%d.%02d", q$Revision: 0.15 $ =~ /(\d+)/g;
+our $VERSION = sprintf "%d.%02d", q$Revision: 0.16 $ =~ /(\d+)/g;
 require XSLoader;
 XSLoader::load( 'Digest::SipHash', $VERSION );
 
 use base 'Exporter';
 our @EXPORT_OK = qw/siphash siphash32/;
 
-use constant {
-    BIG_ENDIAN  => ( pack( "L", 1 ) eq pack( "N", 1 ) ),
-    USE64BITINT => eval { pack 'Q', 1 }
-};
+use constant BIG_ENDIAN => pack( "L", 1 ) eq pack( "N", 1 );
+use constant USE64BITINT => eval { pack 'Q', 1 };
+
 push @EXPORT_OK, 'siphash64' if USE64BITINT;
 our %EXPORT_TAGS = ( all => [@EXPORT_OK] );
 our $DEFAULT_SEED = pack 'C16', map { int( rand(256) ) } ( 0 .. 0xF );
@@ -54,7 +53,7 @@ Digest::SipHash - Perl XS interface to the SipHash algorithm
 
 =head1 VERSION
 
-$Id: SipHash.pm,v 0.15 2013/02/27 04:04:27 dankogai Exp $
+$Id: SipHash.pm,v 0.16 2013/02/28 03:18:03 dankogai Exp dankogai $
 
 =head1 SYNOPSIS
 
